Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1831)

Unified Diff: content/common/site_isolation_policy.h

Issue 1378203002: Handle hosted apps consistently in --isolate-extensions. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/loader/cross_site_resource_handler.cc ('k') | content/common/site_isolation_policy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/site_isolation_policy.h
diff --git a/content/common/site_isolation_policy.h b/content/common/site_isolation_policy.h
index 1b2d2dc2dea8c36b2bab721ff34e8b37f9349f14..86020c0ef5606d38c1a0799b5f266dfddad467af 100644
--- a/content/common/site_isolation_policy.h
+++ b/content/common/site_isolation_policy.h
@@ -25,9 +25,8 @@ class CONTENT_EXPORT SiteIsolationPolicy {
// that only matter for cross-process iframes, to protect the default
// behavior.
//
- // Note: Since cross-process frames will soon be possible by default (e.g. for
- // <iframe src="http://..."> in an extension process), usage should be limited
- // to temporary stop-gaps.
+ // Note: Since cross-process frames will soon be possible by default, usage
+ // should be limited to temporary stop-gaps.
//
// Instead of calling this method, prefer to examine object state to see
// whether a particular frame happens to have a cross-process relationship
@@ -35,17 +34,15 @@ class CONTENT_EXPORT SiteIsolationPolicy {
// particular site merits protection.
static bool AreCrossProcessFramesPossible();
// Returns true if pages loaded from |url|'s site ought to be handled only by
// a renderer process isolated from other sites. If --site-per-process is on
// the command line, this is true for all sites.
//
- // Eventually, this function will be made to return true for only some schemes
- // (e.g. extensions) or a whitelist of sites that we should protect for this
- // user.
- //
- // Although |url| is currently ignored, callers can assume for now that they
- // can pass a full URL here -- they needn't canonicalize it to a site.
- static bool DoesSiteRequireDedicatedProcess(const GURL& url);
+ // |effective_url| must be an effective URL -- practically speaking, that
+ // means that this function should only be called on the UI thread in the
+ // browser process.
+ static bool DoesSiteRequireDedicatedProcess(const GURL& effective_url);
// Returns true if navigation and history code should maintain per-frame
// navigation entries. This is an in-progress feature related to site
« no previous file with comments | « content/browser/loader/cross_site_resource_handler.cc ('k') | content/common/site_isolation_policy.cc » ('j') | no next file with comments »
@@ -35,17 +34,15 @@ class CONTENT_EXPORT SiteIsolationPolicy {
// particular site merits protection.
static bool AreCrossProcessFramesPossible();
- // Returns true if pages loaded from |url|'s site ought to be handled only by
- // a renderer process isolated from other sites. If --site-per-process is on
- // the command line, this is true for all sites.
+ // Returns true if pages loaded from |effective_url| ought to be handled only
+ // by a renderer process isolated from other sites. If --site-per-process is
+ // on the command line, this is true for all sites. In other site isolation
+ // modes, only a subset of sites will require dedicated processes.
//

Powered by Google App Engine
This is Rietveld 408576698